C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine thresholds_read( version )
      implicit none 
      save

C-------------------------------------------------------------------
C !F77
C
C !DESCRIPTION:
C     Read all MOD35 thresholds from parameter file.
C
C !INPUT PARAMETERS:
C     None
C
C !OUTPUT PARAMETERS:
C     VERSION    Version string (RCS Id) for threshold parameter
C                file.
C
C     Defines values for all arrays in the following include files:
C     LandDay_desert_c_thr.inc
C     PolarDay_desert_c_thr.inc
C     LandDay_desert_thr.inc
C     PolarDay_desert_thr.inc
C     LandDay_thr.inc
C     PolarDay_land_thr.inc
C     LandDay_coast_thr.inc
C     PolarDay_coast_thr.inc
C     LandNite_thr.inc
C     PolarNite_land_thr.inc
C     PolarDay_snow_thr.inc
C     Day_snow_thr.inc
C     PolarNite_snow_thr.inc
C     Nite_snow_thr.inc
C     ocean_day_thr.inc
C     PolarDay_ocean_thr.inc
C     ocean_nite_thr.inc
C     PolarNite_ocean_thr.inc
C     shadows_thr.inc
C     snglntr_thr.inc
C     spatial_var_thr.inc
C     noncld_obs_chk.inc
C     snow_mask.inc
C     Antarctic_day_thr.inc
C     swc_ndvi.inc
C
C !REVISION HISTORY:
C
C !TEAM-UNIQUE HEADER:
C     Developed by the MODIS Group, CIMSS/SSEC, UW-Madison.
C
C !DESIGN NOTES:
C     Original version by Liam.Gumley@ssec.wisc.edu
C
C !END
C--------------------------------------------------------------------

c --- Arguments
      character*(*) version

c --- Local variables
      integer number
      integer lrn_thr_par
      character*160 errmsg

c --- defines threshold file
      include 'cloudmask.inc'

c ... Version and satellite ID internal verification
      include 'thresholds_ver.inc'
      include 'platform_name.inc'
                  
c --- Threshold include files
      include 'LandDay_desert_c_thr.inc'
      include 'PolarDay_desert_c_thr.inc'
      include 'LandDay_desert_thr.inc'
      include 'PolarDay_desert_thr.inc'
      include 'LandDay_thr.inc'
      include 'PolarDay_land_thr.inc'
      include 'LandDay_coast_thr.inc'
      include 'PolarDay_coast_thr.inc'
      include 'LandNite_thr.inc'
      include 'PolarNite_land_thr.inc'
      include 'PolarDay_snow_thr.inc'
      include 'Day_snow_thr.inc'
      include 'PolarNite_snow_thr.inc'
      include 'Nite_snow_thr.inc'
      include 'ocean_day_thr.inc'
      include 'PolarDay_ocean_thr.inc'
      include 'ocean_nite_thr.inc'
      include 'PolarNite_ocean_thr.inc'
      include 'shadows_thr.inc'
      include 'snglntr_thr.inc'
      include 'spatial_var_thr.inc'
      include 'noncld_obs_chk.inc'
      include 'snow_mask.inc'
      include 'Antarctic_day_thr.inc'
      include 'swc_ndvi.inc'


c --- set the threshold unit number
      lrn_thr_par = ANC_THRESHOLD_UNIT

c --- Threshold parameter file version
      call param_string( lrn_thr_par, 'rcs_id', version )

c --- Get threshold ID info and perform internal verification.
      call param_string(lrn_thr_par, ver_name, ver_string)
      
      if(platform_name(1:5) .eq. 'Terra' .or. 
     +  platform_name(1:5) .eq. 'terra' .or.
     +  platform_name(1:5) .eq. 'TERRA') then
        if(ver_string(10:14) .ne. thr_satid_terra) then
          write(errmsg,'( ''Incorrect Terra thresholds file in use'')')
          call message('thresholds_read',errmsg ,0,3)
        end if
      else if(platform_name(1:4) .eq. 'Aqua' .or. 
     +  platform_name(1:4) .eq. 'aqua' .or.
     +  platform_name(1:4) .eq. 'AQUA') then
        if(ver_string(10:14) .ne. thr_satid_aqua) then
          write(errmsg,'( ''Incorrect Aqua thresholds file in use'')')
          call message('thresholds_read',errmsg ,0,3)
        end if
      end if
      
c ... Daytime coastal desert thresholds.

      number = 4
      call param_real(lrn_thr_par,'lds11_12hi_c',number,lds11_12hi_c)
      call param_real(lrn_thr_par,'lds11_4hi_c', number,lds11_4hi_c )
      call param_real(lrn_thr_par,'lds11_4lo_c', number,lds11_4lo_c )
      call param_real(lrn_thr_par,'ldsco2_c',    number,ldsco2_c    )
      call param_real(lrn_thr_par,'ldsh20_c',    number,ldsh20_c    )
      call param_real(lrn_thr_par,'ldsref2_c',   number,ldsref2_c   )
      call param_real(lrn_thr_par,'ldsref3_c',   number,ldsref3_c   )

c ... Daytime polar coastal desert thresholds.

      number = 4
      call param_real(lrn_thr_par,'pds11_12hi_c',number,pds11_12hi_c)
      call param_real(lrn_thr_par,'pds11_4hi_c', number,pds11_4hi_c )
      call param_real(lrn_thr_par,'pds11_4lo_c', number,pds11_4lo_c )
      call param_real(lrn_thr_par,'pdsco2_c',    number,pdsco2_c    )
      call param_real(lrn_thr_par,'pdsh20_c',    number,pdsh20_c    )
      call param_real(lrn_thr_par,'pdsref2_c',   number,pdsref2_c   )
      call param_real(lrn_thr_par,'pdsref3_c',   number,pdsref3_c   )

c ... Daytime desert thresholds.

      number = 4
      call param_real(lrn_thr_par,'lds11_12hi',number,lds11_12hi)
      call param_real(lrn_thr_par,'lds11_4hi', number,lds11_4hi )
      call param_real(lrn_thr_par,'lds11_4lo', number,lds11_4lo )
      call param_real(lrn_thr_par,'ldsco2',    number,ldsco2    )
      call param_real(lrn_thr_par,'ldsh20',    number,ldsh20    )
      call param_real(lrn_thr_par,'ldsref2',   number,ldsref2   )
      call param_real(lrn_thr_par,'ldsref3',   number,ldsref3   )
      number = 3
      call param_real(lrn_thr_par,'ldsbt11',   number,ldsbt11   )
      call param_real(lrn_thr_par,'ldsbt11bd', number,ldsbt11bd )

c ... Daytime polar desert thresholds.

      number = 4
      call param_real(lrn_thr_par,'pds11_12hi',number,pds11_12hi)
      call param_real(lrn_thr_par,'pds11_4hi', number,pds11_4hi )
      call param_real(lrn_thr_par,'pds11_4lo', number,pds11_4lo )
      call param_real(lrn_thr_par,'pdsco2',    number,pdsco2    )
      call param_real(lrn_thr_par,'pdsh20',    number,pdsh20    )
      call param_real(lrn_thr_par,'pdsref2',   number,pdsref2   )
      call param_real(lrn_thr_par,'pdsref3',   number,pdsref3   )
      number = 3
      call param_real(lrn_thr_par,'pdsbt11',   number,pdsbt11   )
      call param_real(lrn_thr_par,'pdsbt11bd', number,pdsbt11bd )

c ... Daytime land thresholds.

      number = 1
      call param_real(lrn_thr_par,'dl11_12hi',number,dl11_12hi)
      number = 4
      call param_real(lrn_thr_par,'dl11_4lo',number,dl11_4lo)
      call param_real(lrn_thr_par,'dlco2',   number,dlco2   )
      call param_real(lrn_thr_par,'dlh20',   number,dlh20   )
      call param_real(lrn_thr_par,'dlref1',  number,dlref1  )
      call param_real(lrn_thr_par,'dlref3',  number,dlref3  )
      call param_real(lrn_thr_par,'dlvrat',  number,dlvrat  )

c ... Daytime polar land thresholds.

      number = 1
      call param_real(lrn_thr_par,'pdl11_12hi',number,pdl11_12hi)
      number = 4
      call param_real(lrn_thr_par,'pdl11_4lo',number,pdl11_4lo)
      call param_real(lrn_thr_par,'pdlco2',   number,pdlco2   )
      call param_real(lrn_thr_par,'pdlh20',   number,pdlh20   )
      call param_real(lrn_thr_par,'pdlref1',  number,pdlref1  )
      call param_real(lrn_thr_par,'pdlref3',  number,pdlref3  )
      call param_real(lrn_thr_par,'pdlvrat',  number,pdlvrat  )

c ... Daytime coastal land thresholds.

      number = 1
      call param_real(lrn_thr_par,'dl11_12hi_t2',number,dl11_12hi_t2)
      number = 4
      call param_real(lrn_thr_par,'dl11_4lo_t2',number,dl11_4lo_t2)
      call param_real(lrn_thr_par,'dlco2_t2',   number,dlco2_t2   )
      call param_real(lrn_thr_par,'dlh20_t2',   number,dlh20_t2   )
      call param_real(lrn_thr_par,'dlref1_t2',  number,dlref1_t2  )
      call param_real(lrn_thr_par,'dlref3_t2',  number,dlref3_t2  )

c ... Daytime polar coastal land thresholds.

      number = 1
      call param_real(lrn_thr_par,'pdl11_12hi_t2',number,pdl11_12hi_t2)
      number = 4
      call param_real(lrn_thr_par,'pdl11_4lo_t2',number,pdl11_4lo_t2)
      call param_real(lrn_thr_par,'pdlco2_t2',   number,pdlco2_t2   )
      call param_real(lrn_thr_par,'pdlh20_t2',   number,pdlh20_t2   )
      call param_real(lrn_thr_par,'pdlref1_t2',  number,pdlref1_t2  )
      call param_real(lrn_thr_par,'pdlref3_t2',  number,pdlref3_t2  )

c ... Nighttime land thresholds.

      number = 4
      call param_real(lrn_thr_par,'nl11_4lo',number,nl11_4lo)
      call param_real(lrn_thr_par,'nl4_12hi',number,nl4_12hi)
      call param_real(lrn_thr_par,'nlco2',   number,nlco2   )
      call param_real(lrn_thr_par,'nlh20',   number,nlh20   )
      number = 1
      call param_real(lrn_thr_par,'nl11_12hi',number,nl11_12hi)

c ... Nighttime polar land thresholds.

      number = 4
      call param_real(lrn_thr_par,'pnl11_4lo',number,pnl11_4lo)
      call param_real(lrn_thr_par,'pnl4_12hi',number,pnl4_12hi)
      call param_real(lrn_thr_par,'pnlco2',   number,pnlco2   )
      call param_real(lrn_thr_par,'pnlh20',   number,pnlh20   )
      number = 1
      call param_real(lrn_thr_par,'pnl11_12hi',number,pnl11_12hi)

c ... Daytime polar snow thresholds.

      number = 4
      call param_real(lrn_thr_par,'dps4_11',   number,dps4_11)
      call param_real(lrn_thr_par,'dps4_11hel',number,dps4_11hel)
      call param_real(lrn_thr_par,'dpsco2',    number,dpsco2)
      call param_real(lrn_thr_par,'dpsh20',    number,dpsh20)
      call param_real(lrn_thr_par,'dpsref1',   number,dpsref1)
      call param_real(lrn_thr_par,'dpsref3',   number,dpsref3)

c ... Antarctic day thresholds.

      number = 4
      call param_real(lrn_thr_par,'ant4_11',number,ant4_11)
      call param_real(lrn_thr_par,'anth20', number,anth20)
      call param_real(lrn_thr_par,'antref1',number,antref1)
      call param_real(lrn_thr_par,'antref3',number,antref3)

c ... Daytime snow thresholds.

      number = 4
      call param_real(lrn_thr_par,'ds4_11',   number,ds4_11)
      call param_real(lrn_thr_par,'ds4_11hel',number,ds4_11hel) 
      call param_real(lrn_thr_par,'dsco2',    number,dsco2)
      call param_real(lrn_thr_par,'dsh20',    number,dsh20)
      call param_real(lrn_thr_par,'dsref1',   number,dsref1)
      call param_real(lrn_thr_par,'dsref3',   number,dsref3)

c ... Nighttime polar snow thresholds.

      number = 4
      call param_real(lrn_thr_par,'pns11_4lo',number,pns11_4lo)
      call param_real(lrn_thr_par,'pns4_12hi',number,pns4_12hi)
      call param_real(lrn_thr_par,'pnsco2',   number,pnsco2)
      call param_real(lrn_thr_par,'pnsh20',   number,pnsh20)
      number = 1
      call param_real(lrn_thr_par,'pn65_11',  number,pn65_11)

c ... Nighttime snow thresholds.

      number = 4
      call param_real(lrn_thr_par,'ns11_4lo',number,ns11_4lo)
      call param_real(lrn_thr_par,'ns4_12hi',number,ns4_12hi)
      call param_real(lrn_thr_par,'nsco2',   number,nsco2)
      call param_real(lrn_thr_par,'nsh20',   number,nsh20)
      number = 1
      call param_real(lrn_thr_par,'n65_11',  number,n65_11)

c ... Daytime ocean thresholds.

      number = 1
      call param_real(lrn_thr_par, 'do11_12hi', number, do11_12hi )
      number = 4
      call param_real(lrn_thr_par,'do11_4lo',number,do11_4lo)
      call param_real(lrn_thr_par,'dobt11',  number,dobt11)
      call param_real(lrn_thr_par,'doco2',   number,doco2)
      call param_real(lrn_thr_par,'doh20',   number,doh20)
      call param_real(lrn_thr_par,'doref2',  number,doref2)
      call param_real(lrn_thr_par,'doref3',  number,doref3)
      call param_real(lrn_thr_par,'dovrathi',number,dovrathi)
      call param_real(lrn_thr_par,'dovratlo',number,dovratlo)

c ... Daytime polar ocean thresholds.

      number = 1
      call param_real(lrn_thr_par,'pdo11_12hi',number,pdo11_12hi)
      number = 4
      call param_real(lrn_thr_par,'pdo11_4lo', number,pdo11_4lo)
      call param_real(lrn_thr_par,'pdobt11',   number,pdobt11)
      call param_real(lrn_thr_par,'pdoco2',    number,pdoco2)
      call param_real(lrn_thr_par,'pdoh20',    number,pdoh20)
      call param_real(lrn_thr_par,'pdoref2',   number,pdoref2)
      call param_real(lrn_thr_par,'pdoref3',   number,pdoref3)
      call param_real(lrn_thr_par,'pdovrathi', number,pdovrathi)
      call param_real(lrn_thr_par,'pdovratlo', number,pdovratlo)

c ... Nighttime ocean thresholds.

      number = 1
      call param_real(lrn_thr_par,'no11_12hi',number,no11_12hi)
      number = 4
      call param_real(lrn_thr_par,'no11_4lo', number,no11_4lo)
      call param_real(lrn_thr_par,'nobt11',   number,nobt11)
      call param_real(lrn_thr_par,'noco2',    number,noco2)
      call param_real(lrn_thr_par,'noh20',    number,noh20)
      call param_real(lrn_thr_par,'nosig',    number,nosig)

c ... Nighttime polar ocean thresholds.

      number = 1
      call param_real(lrn_thr_par,'pno11_12hi',number,pno11_12hi)
      number = 4
      call param_real(lrn_thr_par,'pno11_4lo',number,pno11_4lo)
      call param_real(lrn_thr_par,'pnobt11',  number,pnobt11)
      call param_real(lrn_thr_par,'pnoco2',   number,pnoco2)
      call param_real(lrn_thr_par,'pnoh20',   number,pnoh20)
      call param_real(lrn_thr_par,'pnosig',   number,pnosig)

c ... Shadow Thresholds

      number = 2
      call param_real(lrn_thr_par,'shadnir',number,shadnir)
      number = 1
      call param_real(lrn_thr_par,'shavrat',number,shavrat)
      call param_real(lrn_thr_par,'shad124',number,shad124)

c ... Sun Glint Thresholds

      number = 2
      call param_real(lrn_thr_par,'snglnt2',  number,snglnt2)
      call param_real(lrn_thr_par,'snglnt2ch',number,snglnt2ch)
      call param_real(lrn_thr_par,'snglnt2cl',number,snglnt2cl)
      call param_real(lrn_thr_par,'snglntv',  number,snglntv)
      call param_real(lrn_thr_par,'snglntvch',number,snglntvch)
      call param_real(lrn_thr_par,'snglntvcl',number,snglntvcl)
      number = 1
      call param_real(lrn_thr_par,'sg_tbdfl',number,sg_tbdfl)
      call param_real(lrn_thr_par,'sg_tbdfh',number,sg_tbdfh)

c ... Day time ocean spatial variability threshold

      number = 1
      call param_real(lrn_thr_par,'dovar11',number,dovar11)

c ... Non-cloud Obstruction Thresholds

      number = 1
      call param_real(lrn_thr_par,'nc_bt37',number,nc_bt37)
      call param_real(lrn_thr_par,'nc37_11',number,nc37_11)
      call param_real(lrn_thr_par,'nc21',   number,nc21)
      call param_real(lrn_thr_par,'nc11_12',number,nc11_12)
     
c ... Snow Mask Thresholds

      number = 1
      call param_real(lrn_thr_par,'sm_bt11',number,sm_bt11)
      call param_real(lrn_thr_par,'sm_ndsi',number,sm_ndsi)
      call param_real(lrn_thr_par,'sm_ref2',number,sm_ref2)
      call param_real(lrn_thr_par,'sm_ref3',number,sm_ref3)
      call param_real(lrn_thr_par,'sm_co2', number,sm_co2)
      call param_real(lrn_thr_par,'sm85_11',number,sm85_11)
      call param_real(lrn_thr_par,'sm37_11',number,sm37_11)
      call param_real(lrn_thr_par,'sm37_11hel',number,sm37_11hel)

c ... Coast and shallow ocean ndvi thresholds.

      number = 2
      call param_real(lrn_thr_par,'swc_ndvi',number,swc_ndvi)

      END
