C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine get_crad_dat(indat_rad,lines_in_edge,
     +                        klin,ibl,nlin,nc,crad_dat)

      implicit none
      save

c ... Common statement for debug purposes
      common / bug / debug, h_output

c-----------------------------------------------------------------------
c!F77
c
c!DESCRIPTION:  Routine to fill out clear radiance arrays for passing
c               to the clear_radiance suboutine.
c
c!Input Parameters:
c indat_rad     Array containing nlcltx number of lines of
c               reflectance and radiance data 
c lines_in_edge Number of lines outside of processing region
c klin          Current processing line
c ibl           Beginning line of of data to process
c nlin          Total number of lines to process
c nc            Current processing element
c
c!Output Parameters:
c crad_dat      Array containing current pixel of reflectance and
c              radiance values for only the bands used in clear radiance
c               processing
c!Revision History:
c
c!Team-Unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!END
c---------------------------------------------------------------------

      INCLUDE 'global.inc'

c ... array arguments
      real indat_rad(npixel,nlcntx,inband),crad_dat(cr_band)
c ... scalar arguments
      integer klin,ibl,nlin,nc,lines_in_edge

c ... local variables
      integer i,j,k,debug,h_output,kk

c ... local arrays
      integer bands(cr_band)

c ... data statements ..
c ... Array index numbers for bands to be used in clear radiance
c ... processing
      data bands /1,26,6,31,33,34,35,36/

c ... debug statement ............................................
      if (debug .gt. 0) then
        write(h_output,'(10x/,''Subroutine get_crad_dat '',/)')
      endif
c ...............................................................
      
c     Put pixel data into data array.  If working on edge pixels
c     then take either the first or last of 3 in context...otherwise
c     always take the middle line
      if (klin .le. lines_in_edge) then
         i = klin
      else if (klin .gt. nlin-lines_in_edge) then
         i = nlcntx
      else 
         i = ((nlcntx-1) / 2) + 1
      endif 

c     The element number to take is always just the current
c     pixel being processed
      j = nc

c     Fill clear radiance array with values
      do 300 k = 1 , cr_band
          if (k .le. cr_band - cr_ir_band) then 

            if (indat_rad(j,i,bands(k)).gt. 0.0 .and. 
     +          indat_rad(j,i,bands(k)) .lt. 1.0) then
                  crad_dat(k) = indat_rad(j,i,bands(k)) 
            else
                  crad_dat(k) = bad_data
            endif
          else
            if (indat_rad(j,i,bands(k)).gt. 0.0 .and. 
     +          indat_rad(j,i,bands(k)) .lt. 1000.0) then
                  crad_dat(k) = indat_rad(j,i,bands(k)) 
            else
                  crad_dat(k) = bad_data
            endif
          endif
  300 continue

c ... debug statement ............................................
      if (debug .gt. 0) then
        write(h_output,'(15x,'' CLRRAD line  '', I4, '' and element ''
     +       ,I4)') klin+ibl-1, nc
        write(h_output,'(2x,''.66  1.38  1.6 '', /, 3f6.3)')
     +        (crad_dat(kk),kk=1,cr_band-cr_ir_band)
        write(h_output,'(2x,''11.0  13.3  13.6  13.9  14.2  
     + '', /, 5f6.3)') (crad_dat(kk),kk=cr_band-cr_ir_band+1,cr_band)
      endif
c ...............................................................

      return
      end
