C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine polar_nite(pxldat,vza,land,ice,snow,nmtests,testbits,
     +                      uniform,indat,kele,maxele,line_edge,klin,
     +                      qa_bits,confdnc)

      implicit none
      save

c----------------------------------------------------------------------
C!F77 
c
c!Description:
C     Routine for providing conditional input parameters pertaining
C     to polar nighttime processing.
C
c!Input parameters:
c pxldat        Array containing reflectance or brightness temperatures
c               for all bands for a single pixel
c vza           Viewing zenith angle
c land          Logical variable flagging land backgrounds
c ice           Logical variable flagging snow backgrounds
c snow          Logical variable flagging snow backgrounds
c uniform       Logical variable flagging uniform background
c kele          Current element number being processed
c maxele        Maximum number of pixels in a scan
c line_edge     Logical variable indicating first or last line of
c               data in a granule
c klin          Counter indicating number of lines processed
c indat         Array containing 'nlcntx' lines of radiance data
c
c!Output Parameters:
c nmtests       Number of tests applied to this pixel
c testbits      Byte array containing cloud mask results
c qa_bits       Byte array containing qa bit results
c confdnc       Current pixel unobstructed confidence
c
c!Revision History:
c
c!Team-Unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!END
c----------------------------------------------------------------------

      include 'global.inc'

c     scalar arguments
      real confdnc
      logical land,snow,ice,uniform
      integer nmtests,kele,maxele,klin

c     array arguments
      real pxldat(inband),vza,indat(npixel,nlcntx,inband)
      byte testbits(6),qa_bits(10)
      logical line_edge

c     local scalars
      integer debug,h_output
      real sigma_31

c     local arrays
      real rgdata(nlcntx,necntx,var_band)

c     external subroutines
      external PolarNite_snow,PolarNite_land,PolarNite_ocean,get_regstd,
     *         chk_spatial_var

c     Common statement for debug purposes
      common / bug / debug, h_output

c----------------------------------------------------------------------

c     Debug statement.
      if (debug .gt. 0) then
        write(h_output,'(10x/,''Using polar_nite processing path '',/)')
      endif

c----------------------------------------------------------------------

      if (snow .or. ice) then

c        snow or ice covered surfaces
         call PolarNite_snow(pxldat,testbits,qa_bits,nmtests,
     +                       confdnc)

      else if (land) then

c        Land surfaces
         call PolarNite_land(pxldat,vza,testbits,qa_bits,
     +                       nmtests,confdnc)

      else

c        Water surfaces.

c        Get 11 um standard deviation for the current context.
         call get_regstd(indat,kele,maxele,line_edge,klin,rgdata,
     +                   sigma_31)

         call PolarNite_ocean(pxldat,vza,sigma_31,testbits,qa_bits,
     +                        nmtests,confdnc)

      end if

c----------------------------------------------------------------------

c     Debug statement.
      if (debug .gt. 0) then
        write(h_output,'(10x/,'' Polar Nite preliminary confidence '',
     +        f10.2,/)') confdnc
      endif

c----------------------------------------------------------------------

c     Perform clear sky confidence confirmation tests. 

      if(confdnc .le. 0.95 .and. confdnc .gt. 0.05 .and. uniform .and.
     *  (.not. land)) then
        call chk_spatial_var(indat,kele,confdnc,qa_bits,testbits)
      end if

c----------------------------------------------------------------------

      return
      end
