C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine tview(key,xmu,bt11,corr)

      implicit none
      save

C
c-----------------------------------------------------------------------
c!F77
c
c!DESCRIPTION: subroutine which computes the bi-dimensional linear or
c              quadratic interpolation (lagrange form) of a given value
c              to a table of scan angle and 11um brightness temperature
C              dependent 11-12 micron brightness temperature 
c              differences.  These values were taken from APOLLO.
c 
c!Input Parameters:
c key           linear (1) or quadratic (2) interpolation               
c xmu           secant of the viewing zenith angle
c bt11          pixel 11 micron brightness temperature
c
c!Output Parameters:
c corr          computed 11-12 micron BTDIF threshold for 
c               thin cirrus detection
c!Revision History:
c
c!Team-unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c Revision 01.00  1995/7/17 02:35:00
c K. Strabala (kathys@ssec.wisc.edu)
c Initial delivery of software.  Modified to comply with ESDIS and
c MODIS standards.  It was a pain.
c
c!END
c-----------------------------------------------------------------------

c ... scalar arguments ..
      real bt11,corr,xmu
      integer key
c ...
c ... local scalars ..
      real lt0,lt1,lt2,lu0,lu1,lu2,p,p0,p1,p2,t,t0,t1,t2,u,u0,u1,u2
      integer i,i0,i1,i2,ii,j,j0,j1,j2,jj,Iflag
c ...
c ... local arrays ..
      real tab(5,6),ttab(6),utab(5)
c ...
c ... data statements ..
 
      data utab/2.00,1.75,1.5,1.25,1.00/
      data ttab/260.,270.,280.,290.,300.,310./
      data (tab(i,1),i=1,5)/1.10,0.90,0.65,0.60,0.55/
      data (tab(i,2),i=1,5)/1.13,1.03,0.81,0.63,0.58/
      data (tab(i,3),i=1,5)/2.30,2.14,1.88,1.61,1.30/
      data (tab(i,4),i=1,5)/4.73,4.27,3.95,3.72,3.06/
      data (tab(i,5),i=1,5)/8.43,7.42,7.00,6.92,5.77/
      data (tab(i,6),i=1,5)/13.39,11.60,11.03,10.74,9.41/
c ...
c ... initialize variables
      lt0 = 0.0
      lt1 = 0.0
      lt2 = 0.0
      lu0 = 0.0
      lu1 = 0.0
      lu2 = 0.0
      p = 0.0
      p0 = 0.0
      p1 = 0.0
      p2 = 0.0
      t = 0.0
      t0 = 0.0
      t1 = 0.0
      t2 = 0.0
      u = 0.0
      u1 = 0.0
      u2 = 0.0
      i0 = 0
      i1 = 0
      i2 = 0
      j0 = 0
      j1 = 0
      j2 = 0
      jj = 0
 
c ...
c ... bounds check
      u = xmu
      t = bt11
      if (u.gt.utab(1)) u = utab(1)
      if (u.lt.utab(5)) u = utab(5)
      if (t.lt.ttab(1)) t = ttab(1)
      if (t.gt.ttab(6)) t = ttab(6)

c Next block was modified by SDST vlin   09/24/96
c ... select the xmu indicies
c      do 1 i = 2,5
c        ii = i
c        if (u.ge.utab(i)) go to 2
c    1 continue
c    2 if (key.ne.1) go to 3
c      i0 = ii - 1
c      i1 = ii
c      go to 5
c    3 if (ii.eq.5) go to 4
c      i0 = ii - 1
c      i1 = ii
c      i2 = ii + 1
c      go to 5
c    4 i0 = ii - 2
c      i1 = ii - 1
c      i2 = ii

       Iflag = 0
       do 1 i = 2, 5
          ii = i
          if (u.ge.utab(i) .AND. Iflag.eq.0) then
             Iflag = 1
             if (key.eq.1) then
                i0 = ii - 1
                i1 = ii
             else
                if (ii.eq.5) then
                   i0 = ii - 2
                   i1 = ii - 1
                   i2 = ii
                else
                   i0 = ii - 1
                   i1 = ii
                   i2 = ii + 1
                end if
             end if
          end if
    1 continue

c Next block was modified by SDST vlin   09/24/96
c ... select the bt11 indicies
c    5 do 6 j = 2,6
c        jj = j
c        if (t.le.ttab(j)) go to 7
c    6 continue
c    7 if (key.ne.1) go to 8
c      j0 = jj - 1
c      j1 = jj
c      go to 10
c    8 if (jj.eq.6) go to 9
c      j0 = jj - 1
c      j1 = jj
c      j2 = jj + 1
c      go to 10
c    9 j0 = jj - 2
c      j1 = jj - 1
c      j2 = jj
c   10 continue
c ...

       Iflag = 0
       do 6 j = 2, 6
          jj = j
          if (t.le.ttab(j) .AND. Iflag.eq.0) then
             Iflag = 1
             if (key.eq.1) then
                 j0 = jj - 1
                 j1 = jj
             else
                if (jj.eq.6) then
                   j0 = jj - 2
                   j1 = jj - 1
                   j2 = jj
                else
                   j0 = jj - 1
                   j1 = jj
                   j2 = jj + 1
                end if
             end if
          end if
    6 continue

c ... branch on scheme type
c Next line was modified by SDST vlin   09/24/96
c     if (key.ne.1) go to 20
      IF (key.eq.1) THEN

c ... linear scheme
c ... designate index values

      u0 = utab(i0)
      u1 = utab(i1)
      t0 = ttab(j0)
      t1 = ttab(j1)

c ... lagrange polynomials
      lu0 = (u-u1)/ (u0-u1)
      lu1 = (u-u0)/ (u1-u0)
      lt0 = (t-t1)/ (t0-t1)
      lt1 = (t-t0)/ (t1-t0)

c ... interpolating polynomials for the first dimension
      p0 = tab(i0,j0)*lu0 + tab(i1,j0)*lu1
      p1 = tab(i0,j1)*lu0 + tab(i1,j1)*lu1

c ... interpolating polynomial for second dimension
      p = p0*lt0 + p1*lt1
c ...
      corr = p
      return

c 1 line added by SDST vlin   09/24/96
      END IF
c ...
c ... quadratic scheme
c ... designate index values
      u0 = utab(i0)
      u1 = utab(i1)
      u2 = utab(i2)
      t0 = ttab(j0)
      t1 = ttab(j1)
      t2 = ttab(j2)
c ...
c ... lagrange polynomials
      lu0 = (u-u1)* (u-u2)/ (u0-u1)/ (u0-u2)
      lu1 = (u-u0)* (u-u2)/ (u1-u0)/ (u1-u2)
      lu2 = (u-u0)* (u-u1)/ (u2-u0)/ (u2-u1)
      lt0 = (t-t1)* (t-t2)/ (t0-t1)/ (t0-t2)
      lt1 = (t-t0)* (t-t2)/ (t1-t0)/ (t1-t2)
      lt2 = (t-t0)* (t-t1)/ (t2-t0)/ (t2-t1)
c ...
c ...
c ... interpolating polynomials for the first dimension
      p0 = tab(i0,j0)*lu0 + tab(i1,j0)*lu1 + tab(i2,j0)*lu2
      p1 = tab(i0,j1)*lu0 + tab(i1,j1)*lu1 + tab(i2,j1)*lu2
      p2 = tab(i0,j2)*lu0 + tab(i1,j2)*lu1 + tab(i2,j2)*lu2
c ...
c ... interpolating polynomial for second dimension
      p = p0*lt0 + p1*lt1 + p2*lt2
c ...
      corr = p
      return
      end
