C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine water_nite(pxldat,vza,uniform,ice,indat,kele,
     *                      maxele,line_edge,klin,nmtests,testbits,
     *                      qa_bits,confdnc)

      implicit none
      save

c---------------------------------------------------------------------
C!F77 
c
c!Description:
c     Routine for setting appropriate flags and processing path
c     for nighttime observations over water surfaces.
c
c     If the confidence determined from the water background is
c     uncertain, than a spatial variability test is applied if
c     the pixels within the processing context are all from the
c     same ecosystem (not including a coastline).
c
c!Input parameters:
c pxldat        Array containing reflectance or brightness temperatures
c               for all bands for a single pixel
c uniform       Logical variable flagging context of similar ecosystem
c ice           Locical variable flagging ice backgrounds
c indat         Array containing nlcntx lines of data
c kele          Current granule element number being processed
c maxele        Maximum number of pixels in a scan
c line_edge     Logical variable indicating first or last line of
c               data in a granule
c klin          Counter indicating number of lines processed
c vza           Viewing zenith angle
c
c!Output Parameters:
c nmtests       Number of tests applied for this pixel
c testbits      Byte array containing cloud mask results
c qa_bits       10-byte array containing qa bit results
c confdnc       Current pixel unobstructed confidence
c
c!Revision History:
c
c!Team-Unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!END
c---------------------------------------------------------------------
c
      include 'global.inc'
    
c     scalar arguments
      real vza,confdnc
      integer kele,nmtests,maxele,klin
      logical uniform,ice,line_edge
c
c     array arguments
      real pxldat(inband),indat(npixel,nlcntx,inband)
      byte testbits(6),qa_bits(10)

c     local scalars
      integer debug,h_output
      real sigma_31

c     local arrays
      real rgdata(nlcntx,necntx,var_band)

c     external subroutines
      external ocean_nite,Nite_snow,chk_spatial_var,get_regstd

c     Common statement for debug purposes
      common / bug / debug, h_output

c---------------------------------------------------------------------
c
c     Debug statement.
      if (debug .gt. 0) then
        write(h_output,'(10x/,''Using water_nite processing path '',/)')
      endif

c---------------------------------------------------------------------

      if (ice) then
c        Ice processing

         call Nite_snow(pxldat,testbits,qa_bits,nmtests,
     +                  confdnc)

      else

c        Normal nighttime ocean processing

c        Get 11 um standard deviation for the current context.
         call get_regstd(indat,kele,maxele,line_edge,klin,rgdata,
     +                   sigma_31)

         call ocean_nite(pxldat,vza,sigma_31,testbits,qa_bits,
     +                   nmtests,confdnc)

      endif

c---------------------------------------------------------------------

c     Debug statement.
      if (debug .gt. 0) then
        write(h_output,'(10x/,'' Water nite preliminary confidence '',
     +        f10.2,/)') confdnc
      endif

c---------------------------------------------------------------------

c     Perform clear sky confidence confirmation tests.

      if(confdnc .le. 0.95 .and. confdnc .gt. 0.05 .and. uniform) then
        call chk_spatial_var(indat,kele,confdnc,qa_bits,testbits)
      end if

c---------------------------------------------------------------------

      return
      end
